@@ -1,5 +1,6 @@
 import json
 import logging
+from typing import Any, Dict, List, Optional
 
 log = logging.getLogger(__name__)
 
@@ -104,6 +105,56 @@ class CommunitiesMixin(object):
         res = self._perform_request("post", url, data=json.dumps(data), headers=headers)
         return self._process_response(res, [201])
 
+    def create_or_update_communities(
+        self,
+        project_id: str,
+        community_type_id: str,
+        data: Optional[List[Dict[str, Any]]],
+        from_facet: Optional[str],
+    ):
+        """
+        Create or update batch of communities.
+
+        Either `data` or `from_facet` must be filled in the request. Both can't
+        contain values at the same time. It returns the batch ID which can be used to
+        poll for the status of the task.
+
+
+        :param project_id: Project identifier
+        :param community_type_id: Community type identifier
+        :param data: Communities data
+        :param from_facet: Facet name to create communities based on
+
+        :returns: A dictionary containing batch ID and message about the start of
+                creating and updating communities.
+
+        Example::
+
+            >>> client.create_or_update_communities(
+            ...                      project_id='BFXfzPHKQP2xRxAP86Kfig',
+            ...                      community_type_id='G0Tm2SQcTqu2d4GvfyrsMg',
+            ...                      data=[
+            ...                             {"name": "Robert Lewandowski", "facet_value": "Robert Lewandowski"},
+            ...                             {"name": "Cristiano Ronaldo", "facet_value": "Cristiano Ronaldo"},
+            ...                         ]
+            ...                      )
+            {
+                'message': 'Started creating or updating batch of communities for the community type with id "G0Tm2SQcTqu2d4GvfyrsMg"',
+                'batch_id': 'a4iqj_ZBTQiRhux_8XnITw',
+            }
+        """
+        url = (
+            f"{self.topic_api_url}/v0/{self.tenant}/projects/{project_id}"
+            f"/community_types/{community_type_id}/communities/batch"
+        )
+
+        headers = {"Content-Type": "application/json"}
+        payload = {"data": data, "from_facet": from_facet}
+        res = self._perform_request(
+            "post", url, data=json.dumps(payload), headers=headers
+        )
+        return self._process_response(res, [201])
+
     def modify_community(
         self,
         project_id,
