@@ -528,10 +528,12 @@ class DashboardsMixin(object):
         :param dashboard_id: Dashboard identifier
 
         :returns: A dictionary containing:
-        a) permissions: list of the dashboard permission dictionaries.
-        b) is_default: a flag indicating whether these are the default
-        permissions on the dashboard (based on project membership)
-        or not (i.e. based on explicitly saved dashboard permissions)
+
+            * `permissions`: A list of the dashboard permission dictionaries.
+            * `is_default`: a boolean flag indicating whether these are the
+              default permissions on the dashboard (based on project
+              membership) or not (i.e. based on explicitly saved dashboard
+              permissions)
 
         Example::
 
@@ -577,17 +579,16 @@ class DashboardsMixin(object):
 
         :param project_id: Project identifier
         :param dashboard_id: Dashboard identifier
-        :param permissions_list: A list of all the permissions to create
-        The permissions_list must be superset of the default permissions for a
-        dashboard, since it is impossible to remove the admin
-        from a permission list
+        :param permissions_list: A list of all the permissions to create.
+            The permissions_list must be superset of the default permissions
+            for a dashboard, since it is impossible to remove the admin from a
+            permission list
 
         :returns: A list of the users/groups with permissions for the dashboard
 
         Example::
 
-            permissions_list =
-            [
+            permissions_list = [
                 {
                     'user_id': 'some_user_id',
                     'permission': 'view_and_edit',
@@ -629,10 +630,12 @@ class DashboardsMixin(object):
         permissions with one call. It is equivalent to get_dashboard_permissions
         followed by set_dashboard_permissions (with an appropriate response
         handling from the get call)
+
         :param project_id: Project identifier
         :param dashboard_id: Dashboard identifier
+
         :return: 201 if successful, or 400 if the dashboard already had custom
-            permissions in place
+            permissions in place.
         """
         res_get = self.get_dashboard_permissions(project_id, dashboard_id)
         is_default = res_get.get("is_default")
