@@ -6,23 +6,21 @@ import re
 log = logging.getLogger(__name__)
 
 
-class ProjectsMixin(object):
+class ProjectsMixin:
 
-    PROJECT_ATTRIBUTES = set(
-        [
-            "default_search",
-            "title",
-            "description",
-            "default_sort",
-            "locator",
-            "guide_completed_steps",
-            "theme",
-            "integration_dashboards",
-            "first_visit",
-            "newsletter_config",
-            "photo",
-        ]
-    )
+    PROJECT_ATTRIBUTES = {
+        "default_search",
+        "title",
+        "description",
+        "default_sort",
+        "locator",
+        "guide_completed_steps",
+        "theme",
+        "integration_dashboards",
+        "first_visit",
+        "newsletter_config",
+        "photo",
+    }
 
     def get_user_projects(self):
         """Get projects for the provided user.
@@ -39,11 +37,9 @@ class ProjectsMixin(object):
 
         """
 
-        url = "%(ep)s/%(version)s/%(tenant)s/projects" % {
-            "ep": self.topic_api_url,
-            "version": self.version,
-            "tenant": self.tenant,
-        }
+        url = "{ep}/{version}/{tenant}/projects".format(
+            ep=self.topic_api_url, version=self.version, tenant=self.tenant,
+        )
 
         res = self._perform_request("get", url)
         return self._process_response(res)
@@ -63,12 +59,12 @@ class ProjectsMixin(object):
 
         """
 
-        url = "%(ep)s/%(version)s/%(tenant)s/projects/%(project_id)s" % {
-            "ep": self.topic_api_url,
-            "version": self.version,
-            "tenant": self.tenant,
-            "project_id": project_id,
-        }
+        url = "{ep}/{version}/{tenant}/projects/{project_id}".format(
+            ep=self.topic_api_url,
+            version=self.version,
+            tenant=self.tenant,
+            project_id=project_id,
+        )
 
         res = self._perform_request("get", url)
         return self._process_response(res)
@@ -119,11 +115,9 @@ class ProjectsMixin(object):
             {u'id': u'gd9eIipOQ-KobU0SwJ8VcQ'}
         """
 
-        url = "%(ep)s/%(version)s/%(tenant)s/projects" % {
-            "ep": self.topic_api_url,
-            "version": self.version,
-            "tenant": self.tenant,
-        }
+        url = "{ep}/{version}/{tenant}/projects".format(
+            ep=self.topic_api_url, version=self.version, tenant=self.tenant,
+        )
 
         # build data
         data = {"title": title}
@@ -169,7 +163,6 @@ class ProjectsMixin(object):
         import_machinelearning_jobs=True,
         import_machinelearning_models=True,
         import_project_configuration=True,
-        import_project_configuration_values=True,
         import_project_translations=True,
         import_project_picture=True,
         import_smartfilters=True,
@@ -244,8 +237,6 @@ class ProjectsMixin(object):
             machinelearning models. Defaults to `True`.
         :param import_project_configuration: Boolean. Whether to include the
             project configuration, defaults to `True`.
-        :param import_project_configuration_values: Boolean. Whether to include
-            the import_project_configuration_values, defaults to `True`.
         :param import_project_translations: Boolean. Whether to include the
             project translations, defaults to `True`.
         :param import_project_picture: Boolean. Whether to include the
@@ -274,11 +265,9 @@ class ProjectsMixin(object):
             {u'id': u'gd9eIipOQ-KobU0SwJ8VcQ'}
         """
 
-        url = "%(ep)s/%(version)s/%(tenant)s/projects_from_template" % {
-            "ep": self.topic_api_url,
-            "version": self.version,
-            "tenant": self.tenant,
-        }
+        url = "{ep}/{version}/{tenant}/projects_from_template".format(
+            ep=self.topic_api_url, version=self.version, tenant=self.tenant,
+        )
 
         # build data
         data = {"title": title}
@@ -314,7 +303,6 @@ class ProjectsMixin(object):
             "import_machinelearning_models": import_machinelearning_models,
             "import_pipeline_workflows": import_pipeline_workflows,
             "import_project_configuration": import_project_configuration,
-            "import_project_configuration_values": import_project_configuration_values,
             "import_project_translations": import_project_translations,
             "import_project_picture": import_project_picture,
             "import_smartfilters": import_smartfilters,
@@ -348,12 +336,12 @@ class ProjectsMixin(object):
             ...                       title='My Other Project')
 
         """
-        url = "%(ep)s/%(version)s/%(tenant)s/projects/%(project_id)s" % {
-            "ep": self.topic_api_url,
-            "version": self.version,
-            "tenant": self.tenant,
-            "project_id": project_id,
-        }
+        url = "{ep}/{version}/{tenant}/projects/{project_id}".format(
+            ep=self.topic_api_url,
+            version=self.version,
+            tenant=self.tenant,
+            project_id=project_id,
+        )
 
         # build data
         data = {}
@@ -376,12 +364,12 @@ class ProjectsMixin(object):
 
         """
 
-        url = "%(ep)s/%(version)s/%(tenant)s/projects/%(project_id)s" % {
-            "ep": self.topic_api_url,
-            "version": self.version,
-            "tenant": self.tenant,
-            "project_id": project_id,
-        }
+        url = "{ep}/{version}/{tenant}/projects/{project_id}".format(
+            ep=self.topic_api_url,
+            version=self.version,
+            tenant=self.tenant,
+            project_id=project_id,
+        )
 
         res = self._perform_request("delete", url)
         self._process_response(res, [204])
@@ -418,12 +406,12 @@ class ProjectsMixin(object):
 
         """
 
-        url = "%(ep)s/%(version)s/%(tenant)s/projects/%(project_id)s/reset" % {
-            "ep": self.topic_api_url,
-            "version": self.version,
-            "tenant": self.tenant,
-            "project_id": project_id,
-        }
+        url = "{ep}/{version}/{tenant}/projects/{project_id}/reset".format(
+            ep=self.topic_api_url,
+            version=self.version,
+            tenant=self.tenant,
+            project_id=project_id,
+        )
 
         headers = {"Content-Type": "application/json"}
 
@@ -432,7 +420,7 @@ class ProjectsMixin(object):
             "reset_elasticsearch_index": reset_elasticsearch_index,
             "reset_facets": reset_facets,
         }
-        data = dict([(k, v) for k, v in args.items() if v is not None])
+        data = {k: v for k, v in args.items() if v is not None}
 
         if data:
             res = self._perform_request(
@@ -462,7 +450,6 @@ class ProjectsMixin(object):
         export_machinelearning_jobs=True,
         export_machinelearning_models=True,
         export_project_configuration=True,
-        export_project_configuration_values=True,
         export_project_translations=True,
         export_project_picture=True,
         export_smartfilters=True,
@@ -545,8 +532,6 @@ class ProjectsMixin(object):
             machinelearning models. Defaults to `True`.
         :param export_project_configuration: Boolean. Whether to include the
             project configuration, defaults to `True`.
-        :param export_project_configuration_values: Boolean. Whether to include
-            the export_project_configuration_values, defaults to `True`.
         :param export_project_translations: Boolean. Whether to include the
             project translations, defaults to `True`.
         :param export_project_picture: Boolean. Whether to include the
@@ -580,12 +565,12 @@ class ProjectsMixin(object):
         For saving the archive, refer to :func:`get_project_export` method.
         """
 
-        url = "%(ep)s/%(version)s/%(tenant)s/projects/%(project_id)s/export" % {
-            "ep": self.topic_api_url,
-            "version": self.version,
-            "tenant": self.tenant,
-            "project_id": project_id,
-        }
+        url = "{ep}/{version}/{tenant}/projects/{project_id}/export".format(
+            ep=self.topic_api_url,
+            version=self.version,
+            tenant=self.tenant,
+            project_id=project_id,
+        )
 
         headers = {"Content-Type": "application/json"}
 
@@ -606,7 +591,6 @@ class ProjectsMixin(object):
             "export_machinelearning_models": export_machinelearning_models,
             "export_pipeline_workflows": export_pipeline_workflows,
             "export_project_configuration": export_project_configuration,
-            "export_project_configuration_values": export_project_configuration_values,
             "export_project_translations": export_project_translations,
             "export_project_picture": export_project_picture,
             "export_smartfilters": export_smartfilters,
@@ -621,7 +605,7 @@ class ProjectsMixin(object):
         }
         export_options["token"] = self.refresh_token
 
-        data = dict([(k, v) for k, v in export_options.items() if v is not None])
+        data = {k: v for k, v in export_options.items() if v is not None}
 
         res = self._perform_request("post", url, data=json.dumps(data), headers=headers)
 
@@ -657,12 +641,12 @@ class ProjectsMixin(object):
                 f.write(ret.get('data'))
         """
 
-        url = "%(ep)s/%(version)s/%(tenant)s/projects/%(project_id)s/export" % {
-            "ep": self.topic_api_url,
-            "version": self.version,
-            "tenant": self.tenant,
-            "project_id": project_id,
-        }
+        url = "{ep}/{version}/{tenant}/projects/{project_id}/export".format(
+            ep=self.topic_api_url,
+            version=self.version,
+            tenant=self.tenant,
+            project_id=project_id,
+        )
 
         headers = {"Content-Type": "application/json"}
 
@@ -705,7 +689,6 @@ class ProjectsMixin(object):
         import_machinelearning_jobs=True,
         import_machinelearning_models=True,
         import_project_configuration=True,
-        import_project_configuration_values=True,
         import_project_translations=True,
         import_project_picture=True,
         import_smartfilters=True,
@@ -785,8 +768,6 @@ class ProjectsMixin(object):
             machinelearning models. Defaults to `True`.
         :param import_project_configuration: Boolean. Whether to include the
             project configuration, defaults to `True`.
-        :param import_project_configuration_values: Boolean. Whether to include
-            the import_project_configuration_values, defaults to `True`.
         :param import_project_translations: Boolean. Whether to include the
             project translations, defaults to `True`.
         :param import_project_picture: Boolean. Whether to include the
@@ -816,12 +797,12 @@ class ProjectsMixin(object):
                     {'dashboards': False})
         """
 
-        url = "%(ep)s/%(version)s/%(tenant)s/projects/%(project_id)s/import" % {
-            "ep": self.topic_api_url,
-            "version": self.version,
-            "tenant": self.tenant,
-            "project_id": project_id,
-        }
+        url = "{ep}/{version}/{tenant}/projects/{project_id}/import".format(
+            ep=self.topic_api_url,
+            version=self.version,
+            tenant=self.tenant,
+            project_id=project_id,
+        )
 
         headers = {"Content-Type": "application/json"}
 
@@ -842,7 +823,6 @@ class ProjectsMixin(object):
             "import_machinelearning_models": import_machinelearning_models,
             "import_pipeline_workflows": import_pipeline_workflows,
             "import_project_configuration": import_project_configuration,
-            "import_project_configuration_values": import_project_configuration_values,
             "import_project_translations": import_project_translations,
             "import_project_picture": import_project_picture,
             "import_smartfilters": import_smartfilters,
@@ -856,7 +836,7 @@ class ProjectsMixin(object):
         }
         import_options["token"] = self.refresh_token
 
-        data = dict([(k, v) for k, v in import_options.items() if v is not None])
+        data = {k: v for k, v in import_options.items() if v is not None}
 
         with open(project_archive, "rb") as f:
             data["archive"] = base64.b64encode(f.read()).decode("utf-8")
