@@ -74,6 +74,45 @@ class UserApiMixin(object):
 
         return self._process_response(res)
 
+    def change_user_password(
+        self, user_id, current_password, new_password, new_password_confirm,
+    ):
+        """
+        Change a user's password.
+
+        :param user_id: User identifier.
+        :param current_password: User's current password.
+        :param new_password: User's new password.
+        :param new_password_confirm: User's new password for confirmation.
+        """
+        headers = {"Content-Type": "application/json"}
+
+        url = "%(endpoint)s/%(version)s/%(tenant)s/users/%(user)s/password" % {
+            "endpoint": self.user_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+            "user": user_id,
+        }
+
+        data = {
+            "current_password": current_password,
+            "new_password": new_password,
+            "new_password_confirm": new_password_confirm,
+        }
+
+        res = self._perform_request("put", url, data=json.dumps(data), headers=headers)
+        return self._process_response(res)
+
+    def get_users_password_policy(self):
+        """Retrieve the password policy for users' passwords."""
+        url = "%(endpoint)s/%(version)s/%(tenant)s/users/password_policy" % {
+            "endpoint": self.user_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+        }
+        res = self._perform_request("get", url)
+        return self._process_response(res)
+
     def get_authentication(self, user_id, service):
         """Retrieves an authentication for a given service.
 
@@ -94,7 +133,7 @@ class UserApiMixin(object):
         """
 
         url = (
-            "%(ep)s/%(version)s/%(tenant)s" "/authentications/%(service)s/%(user_id)s"
+            "%(ep)s/%(version)s/%(tenant)s/authentications/%(service)s/%(user_id)s"
         ) % {
             "ep": self.user_api_url,
             "version": self.version,
@@ -147,7 +186,7 @@ class UserApiMixin(object):
         """
 
         url = (
-            "%(ep)s/%(version)s/%(tenant)s" "/authentications/%(service)s/%(user_id)s"
+            "%(ep)s/%(version)s/%(tenant)s/authentications/%(service)s/%(user_id)s"
         ) % {
             "ep": self.user_api_url,
             "version": self.version,
@@ -190,7 +229,7 @@ class UserApiMixin(object):
         """
 
         url = (
-            "%(ep)s/%(version)s/%(tenant)s" "/authentications/%(service)s/%(user_id)s"
+            "%(ep)s/%(version)s/%(tenant)s/authentications/%(service)s/%(user_id)s"
         ) % {
             "ep": self.user_api_url,
             "version": self.version,
